==> viur_core-3.1.0-py3-none-any.whl: viur/core/bones/colorBone.py <==
# -*- coding: utf-8 -*-
from viur.core.bones import baseBone
from viur.core.bones.bone import ReadFromClientError, ReadFromClientErrorSeverity
import logging
from typing import List, Union


class colorBone(baseBone):
	type = "color"

	def __init__(self, mode="rgb", *args, **kwargs):  # mode rgb/rgba
		baseBone.__init__(self, *args, **kwargs)
		assert mode in {"rgb", "rgba"}
		self.mode = mode

	def singleValueFromClient(self, value, skel, name, origData):
		value = value.lower()
		if value.count("#") > 1:
			return self.getEmptyValue(), [
				ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		for char in value:
			if not char in "#0123456789abcdef":
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		if self.mode == "rgb":
			if len(value) == 3:
				value = "#" + value
			if len(value) == 4:
				value = value[0:2] + value[1] + 2 * value[2] + 2 * value[3]
			if len(value) == 6 or len(value) == 7:
				if len(value) == 6:
					value = "#" + value
			else:
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		if self.mode == "rgba":
			if len(value) == 8 or len(value) == 9:
				if len(value) == 8:
					value = "#" + value
			else:
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		err = self.isInvalid(value)
		if not err:
			return value, None
		return self.getEmptyValue(), [ReadFromClientError(ReadFromClientErrorSeverity.Invalid, err)]

==> viur_core-3.1.4-py3-none-any.whl: viur/core/bones/colorBone.py <==
# -*- coding: utf-8 -*-
from viur.core.bones import baseBone
from viur.core.bones.bone import ReadFromClientError, ReadFromClientErrorSeverity
import logging
from typing import List, Union


class colorBone(baseBone):
	type = "color"

	def __init__(self, *, mode="rgb", **kwargs):  # mode rgb/rgba
		super().__init__(**kwargs)
		assert mode in {"rgb", "rgba"}
		self.mode = mode

	def singleValueFromClient(self, value, skel, name, origData):
		value = value.lower()
		if value.count("#") > 1:
			return self.getEmptyValue(), [
				ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		for char in value:
			if not char in "#0123456789abcdef":
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		if self.mode == "rgb":
			if len(value) == 3:
				value = "#" + value
			if len(value) == 4:
				value = value[0:2] + value[1] + 2 * value[2] + 2 * value[3]
			if len(value) == 6 or len(value) == 7:
				if len(value) == 6:
					value = "#" + value
			else:
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		if self.mode == "rgba":
			if len(value) == 8 or len(value) == 9:
				if len(value) == 8:
					value = "#" + value
			else:
				return self.getEmptyValue(), [
					ReadFromClientError(ReadFromClientErrorSeverity.Invalid, "Invalid value entered")]
		err = self.isInvalid(value)
		if not err:
			return value, None
		return self.getEmptyValue(), [ReadFromClientError(ReadFromClientErrorSeverity.Invalid, err)]
